==> deepin-boot-maker_2.0.4.4.orig.tar.xz: deepin-boot-maker-2.0.4.4/src/translations/deepin-boot-maker_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation>Провалено повикване на команда %1.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation>Грешка при форматиране: Моля форматирайте диска с FAT32</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation>Недостиг на място: Моля уверете се, че диска има %1 свободно пространство</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation>Грешка при монтиране: Включете отново диска или рестартирайте системата</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation>Грешка при декомпресиране: Моля проверете md5 сумата на образа и се уверете, че той е цял</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation>Вътрешна грешка</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation>Deepin Boot Maker е опростен инструмент за запис на системен образ на CD/DVD, USB устройство и други инсталационни медии.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation>Изберете файл си ISO образ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation>Влачете файл с ISO образ и го пуснете тук</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation>ИЛИ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation>Изберете файл с ISO образ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>Следващ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="156"/>
        <source>Reselect an ISO image file</source>
        <translation>Нов избор на файл с ISO образ</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation>Прави се</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation>Прави се дискът, почакайте…</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation>Моля не премахвайте диска или не спирайте системата при правенето</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="39"/>
        <source>Removable Disk</source>
        <translation>Отстраняващ се диск</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="108"/>
        <source>Removable disk</source>
        <translation>Преносим диск</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation>Рестартирай сега</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation>Успешно завършване</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation>Доклада с грешките ще се изпрати сам с отзива. Без вашата обратна връзка и подкрепа, не можем да станем по-добри.</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation>Отзив</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation>Съжалявам, правенето се провали</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation>Правеното се провали</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation>Моля изберете диск</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formating disk can increase the making success rate</source>
        <translation>Форматирането на диска помага за успешно създаване</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation>Не е намерен достъпен диск</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation>Започване</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely  deleted by formating, please confirm and continue</source>
        <translation>Диска ще бъде изтрит с форматиране, моля потвърдете и продължете</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_2.0.4.9.orig.tar.xz: deepin-boot-maker-2.0.4.9/src/translations/deepin-boot-maker_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation>Провалено повикване на команда %1.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation>Грешка при форматиране: Моля форматирайте диска с FAT32</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation>Недостиг на място: Моля уверете се, че диска има %1 свободно пространство</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation>Грешка при монтиране: Включете отново диска или рестартирайте системата</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation>Грешка при декомпресиране: Моля проверете md5 сумата на образа и се уверете, че той е цял</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation>Вътрешна грешка</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation>Deepin Boot Maker е опростен инструмент за запис на системен образ на CD/DVD, USB устройство и други инсталационни медии.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation>Изберете файл си ISO образ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation>Влачете файл с ISO образ и го пуснете тук</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation>ИЛИ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation>Изберете файл с ISO образ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>Следващ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="162"/>
        <source>Reselect an ISO image file</source>
        <translation>Нов избор на файл с ISO образ</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation>Прави се</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation>Прави се дискът, почакайте…</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation>Моля не премахвайте диска или не спирайте системата при правенето</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Отстраняващ се диск</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="118"/>
        <source>Removable disk</source>
        <translation>Преносим диск</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation>Рестартирай сега</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation>Успешно завършване</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation>Доклада с грешките ще се изпрати сам с отзива. Без вашата обратна връзка и подкрепа, не можем да станем по-добри.</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation>Отзив</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation>Съжалявам, правенето се провали</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation>Правеното се провали</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation>Моля изберете диск</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formatting disk can increase the making success rate</source>
        <translation>Форматирането на диска може да увеличи успеха</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation>Не е намерен достъпен диск</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation>Започване</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely deleted by formatting, please confirm and continue</source>
        <translation>Данните на диска ще бъдат напълно изтрити чрез форматиране, моля потвърдете и продължете</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Format USB flash drive</source>
        <translation>Форматиране на USB устройство</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="233"/>
        <source>All data will be lost during formatting, please back up in advance and then press OK button.</source>
        <translation>Всички данни ще бъдат загубени при форматирането, моля направете резерно копие предварително и след това натиснете OK бутона.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="235"/>
        <source>Ok</source>
        <translation>Добре</translation>
    </message>
</context>
</TS>
